"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.HttpPublisher = exports.Publisher = exports.ProgressCallback = undefined;

var _bluebirdLst;

function _load_bluebirdLst() {
    return _bluebirdLst = require("bluebird-lst");
}

var _progress;

function _load_progress() {
    return _progress = require("./progress");
}

Object.defineProperty(exports, "ProgressCallback", {
    enumerable: true,
    get: function () {
        return (_progress || _load_progress()).ProgressCallback;
    }
});
exports.getCiTag = getCiTag;

var _builderUtil;

function _load_builderUtil() {
    return _builderUtil = require("builder-util");
}

var _builderUtilRuntime;

function _load_builderUtilRuntime() {
    return _builderUtilRuntime = require("builder-util-runtime");
}

var _chalk;

function _load_chalk() {
    return _chalk = _interopRequireDefault(require("chalk"));
}

var _fsExtraP;

function _load_fsExtraP() {
    return _fsExtraP = require("fs-extra-p");
}

var _path = require("path");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const progressBarOptions = {
    incomplete: " ",
    width: 20
};
class Publisher {
    constructor(context) {
        this.context = context;
    }
    createProgressBar(fileName, size) {
        if (this.context.progress == null) {
            (0, (_builderUtil || _load_builderUtil()).log)(`Uploading ${fileName} to ${this.providerName}`);
            return null;
        } else {
            return this.context.progress.createBar(`[:bar] :percent :etas | ${(_chalk || _load_chalk()).default.green(fileName)} to ${this.providerName}`, Object.assign({ total: size }, progressBarOptions));
        }
    }
    createReadStreamAndProgressBar(file, fileStat, progressBar, reject) {
        const fileInputStream = (0, (_fsExtraP || _load_fsExtraP()).createReadStream)(file);
        fileInputStream.on("error", reject);
        if (progressBar == null) {
            return fileInputStream;
        } else {
            const progressStream = new (_builderUtilRuntime || _load_builderUtilRuntime()).ProgressCallbackTransform(fileStat.size, this.context.cancellationToken, it => progressBar.tick(it.delta));
            progressStream.on("error", reject);
            return fileInputStream.pipe(progressStream);
        }
    }
}
exports.Publisher = Publisher;
class HttpPublisher extends Publisher {
    constructor(context, useSafeArtifactName = false) {
        super(context);
        this.context = context;
        this.useSafeArtifactName = useSafeArtifactName;
    }
    upload(task) {
        var _this = this;

        return (0, (_bluebirdLst || _load_bluebirdLst()).coroutine)(function* () {
            const fileName = (_this.useSafeArtifactName ? task.safeArtifactName : null) || (0, _path.basename)(task.file);
            if (task.fileContent != null) {
                yield _this.doUpload(fileName, task.arch || (_builderUtil || _load_builderUtil()).Arch.x64, task.fileContent.length, function (it) {
                    return it.end(task.fileContent);
                });
                return;
            }
            const fileStat = yield (0, (_fsExtraP || _load_fsExtraP()).stat)(task.file);
            const progressBar = _this.createProgressBar(fileName, fileStat.size);
            yield _this.doUpload(fileName, task.arch || (_builderUtil || _load_builderUtil()).Arch.x64, fileStat.size, function (request, reject) {
                if (progressBar != null) {
                    // reset (because can be called several times (several attempts)
                    progressBar.update(0);
                }
                return _this.createReadStreamAndProgressBar(task.file, fileStat, progressBar, reject).pipe(request);
            }, task.file);
        })();
    }
}
exports.HttpPublisher = HttpPublisher;
function getCiTag() {
    const tag = process.env.TRAVIS_TAG || process.env.APPVEYOR_REPO_TAG_NAME || process.env.CIRCLE_TAG || process.env.BITRISE_GIT_TAG || process.env.CI_BUILD_TAG;
    return tag != null && tag.length > 0 ? tag : null;
}
//# sourceMappingURL=publisher.js.map